#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_LOGICAL_AND_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_LOGICAL_AND_HPP_INCLUDED

#include <boost/simd/operator/include/functions/simd/logical_and.hpp>

#endif
